@@ -43,23 +43,24 @@ class Args(object):
         self.no_check = None
         self.keep = None
 
-        # Boost
-        self.boost = None
-        self.boost_range = None
-        self.boost_limit = None
-
         # Vmaf
         self.vmaf = None
         self.vmaf_path = None
+        self.vmaf_res = None
 
         # Target Vmaf
         self.vmaf_target = None
         self.vmaf_steps = None
-        self.min_cq = None
-        self.max_cq = None
+        self.min_q = None
+        self.max_q = None
         self.vmaf_plots = None
+        self.vmaf_rate = None
         self.n_threads = None
 
+        # VVC
+        self.vvc_conf = None
+        self.video_dimensions = (None, None)
+        self.video_framerate = None
         for key in initial_data:
             setattr(self, key, initial_data[key])
 
@@ -89,7 +90,7 @@ def arg_parsing():
     parser.add_argument('--passes', '-p', type=int, default=None, help='Specify encoding passes', choices=[1, 2])
     parser.add_argument('--video_params', '-v', type=str, default=None, help='encoding settings')
     parser.add_argument('--encoder', '-enc', type=str, default='aom', help='Choosing encoder',
-                        choices=['aom', 'svt_av1', 'rav1e', 'vpx','x265'])
+                        choices=['aom', 'svt_av1', 'rav1e', 'vpx','x265', 'x264', 'vvc'])
     parser.add_argument('--workers', '-w', type=int, default=0, help='Number of workers')
     parser.add_argument('-cfg', '--config', type=Path, help='Parameters file. Save/Read: '
                                                             'Video, Audio, Encoder, FFmpeg parameteres')
@@ -105,22 +106,21 @@ def arg_parsing():
     parser.add_argument('--no_check', '-n', help='Do not check encodings', action='store_true')
     parser.add_argument('--keep', help='Keep temporally folder after encode', action='store_true')
 
-    # Boost
-    parser.add_argument('--boost', help='Experimental feature, decrease CQ of clip based on brightness.'
-                                        'Darker = lower CQ', action='store_true')
-    parser.add_argument('--boost_range', '-br', default=15, type=int, help='Range/strength of CQ change')
-    parser.add_argument('--boost_limit', '-bl', default=10, type=int, help='CQ limit for boosting')
-
     # Vmaf
     parser.add_argument('--vmaf', help='Calculating vmaf after encode', action='store_true')
     parser.add_argument('--vmaf_path', type=Path, default=None, help='Path to vmaf models')
+    parser.add_argument('--vmaf_res', type=str, default="1920x1080", help='Resolution used in vmaf calculation')
 
     # Target Vmaf
     parser.add_argument('--vmaf_target', type=float, help='Value of Vmaf to target')
-    parser.add_argument('--vmaf_steps', type=int, default=5, help='Steps between min and max qp for target vmaf')
-    parser.add_argument('--min_cq', type=int, default=None, help='Min cq for target vmaf')
-    parser.add_argument('--max_cq', type=int, default=None, help='Max cq for target vmaf')
+    parser.add_argument('--vmaf_steps', type=int, default=4, help='Steps between min and max qp for target vmaf')
+    parser.add_argument('--min_q', type=int, default=None, help='Min q for target vmaf')
+    parser.add_argument('--max_q', type=int, default=None, help='Max q for target vmaf')
     parser.add_argument('--vmaf_plots', help='Make plots of probes in temp folder', action='store_true')
+    parser.add_argument('--vmaf_rate', type=int, default=4, help='Framerate for probes, 0 - original')
     parser.add_argument('--n_threads', type=int, default=None, help='Threads for vmaf calculation')
 
+    # VVC
+    parser.add_argument('--vvc_conf', type=Path, default=None, help='Path to VVC confing file')
+
     return Args(vars(parser.parse_args()))
