@@ -6,7 +6,6 @@ import sys
 from collections import deque
 from multiprocessing.managers import BaseManager
 from subprocess import PIPE, STDOUT
-
 from tqdm import tqdm
 
 from .utils import terminate
@@ -23,7 +22,7 @@ class Counter():
         self.first_update = True
         self.initial = initial
         self.left = total - initial
-        self.tqdm_bar = tqdm(total=self.left, initial=0, dynamic_ncols=True, unit="fr", leave=True, smoothing=0.2)
+        self.tqdm_bar = tqdm(total=self.left, initial=0, dynamic_ncols=True, unit="fr", leave=True, smoothing=0.01)
 
     def update(self, value):
         if self.first_update:
@@ -46,6 +45,12 @@ def make_pipes(command):
     return pipe
 
 
+def make_vvc_pipe(command):
+    pipe = subprocess.Popen(command.split(), stdout=PIPE,
+                            stderr=STDOUT,
+                            universal_newlines=True)
+    return pipe
+
 def match_aom_vpx(line):
     if 'fatal' in line.lower():
         print('\n\nERROR IN ENCODING PROCESS\n\n', line)
@@ -53,6 +58,7 @@ def match_aom_vpx(line):
     if 'Pass 2/2' in line or 'Pass 1/1' in line:
         return re.search(r"frame.*?\/([^ ]+?) ", line)
 
+
 def match_rav1e(line):
     if 'error' in line.lower():
         print('\n\nERROR IN ENCODING PROCESS\n\n', line)
@@ -60,6 +66,10 @@ def match_rav1e(line):
     return re.search(r"encoded.*? ([^ ]+?) ", line)
 
 
+def match_vvc(line):
+    return re.search(r"POC.*? ([^ ]+?)", line)
+
+
 def process_encoding_pipe(pipe, encoder, counter):
     encoder_history = deque(maxlen=20)
     frame = 0
@@ -80,7 +90,11 @@ def process_encoding_pipe(pipe, encoder, counter):
         elif encoder == 'rav1e':
             match = match_rav1e(line)
 
-        if encoder in  ('x265'):
+        elif encoder in ('x264'):
+            if not skip_1_pass:
+                match = re.search(r"^[^\d]*(\d+)", line)
+
+        elif encoder in  ('x265'):
             if not skip_1_pass and pass_1_check:
                 if 'output file' in line:
                     if 'nul' in line.lower():
@@ -90,6 +104,12 @@ def process_encoding_pipe(pipe, encoder, counter):
             if not skip_1_pass:
                 match = re.search(r"^(\d+)", line)
 
+        elif encoder in ('vvc'):
+            match = match_vvc(line)
+            if match:
+                counter.update(1)
+                continue
+
         if match:
             new = int(match.group(1))
             if new > frame:
@@ -106,16 +126,19 @@ def process_encoding_pipe(pipe, encoder, counter):
 
 def tqdm_bar(i, encoder, counter, frame_probe_source, passes):
     try:
-        pipe = make_pipes(i)
 
-        if encoder in ('aom', 'vpx', 'rav1e','x265'):
+        if encoder in 'vvc':
+            pipe = make_vvc_pipe(i)
+        else:
+            pipe = make_pipes(i)
+
+        if encoder in ('aom', 'vpx', 'rav1e','x265', 'x264', 'vvc'):
             process_encoding_pipe(pipe, encoder, counter)
 
         if encoder == 'svt_av1':
             # SVT-AV1 developer: SVT-AV1 is special in the way it outputs to console
             pipe.wait()
             counter.update(frame_probe_source // passes)
-
     except Exception as e:
         _, _, exc_tb = sys.exc_info()
-        print(f'Error at encode {e}\nAt line {exc_tb.tb_lineno}')
+        print(f'Error at encode {e}\nAt line {exc_tb.tb_lineno}')
\ No newline at end of file
