@@ -4,10 +4,10 @@ import json
 import os
 import sys
 from pathlib import Path
-
+from .vvc import to_yuv
 from .utils import terminate
-
 from .logger import log
+from .ffmpeg import frame_probe
 
 
 def compose_aomsplit_first_pass_command(video_path: Path, stat_file, ffmpeg_pipe, video_params):
@@ -43,9 +43,11 @@ def get_default_params_for_encoder(enc):
     DEFAULT_ENC_PARAMS = {
     'vpx': '--codec=vp9 --threads=4 --cpu-used=0 --end-usage=q --cq-level=30',
     'aom': '--threads=4 --cpu-used=6 --end-usage=q --cq-level=30',
-    'rav1e': ' --tiles 8 --speed 6 --quantizer 100',
+    'rav1e': ' --tiles 8 --speed 6 --quantizer 100 ',
     'svt_av1': ' --preset 4 --rc 0 --qp 25 ',
     'x265': ' -p slow --crf 23 ',
+    'x264': ' --preset slow --crf 23 ',
+    'vvc': ' -wdt 640 -hgt 360 -fr 23.98 -q 30 '
     }
 
     return DEFAULT_ENC_PARAMS[enc]
@@ -150,9 +152,41 @@ def rav1e_encode(inputs, passes, pipe, params):
     return commands
 
 
+def x264_encode(inputs, passes, pipe, params):
+    """
+    Generates commands for x264 encoder
+
+    :param inputs: Files that need to be enocoded
+    :param passes: Encoding passes
+    :param pipe: FFmpeg piping settings
+    :param params: Encoding parameters
+    :return: Composed commands for execution
+    """
+
+    commands = []
+    single_p = 'x264 --stitchable --log-level error --demuxer y4m '
+    two_p_1 = 'x264 --stitchable --log-level error --pass 1 --demuxer y4m '
+    two_p_2 = 'x264 --stitchable --log-level error --pass 2 --demuxer y4m '
+
+    if passes == 1:
+        commands = [
+                (f'ffmpeg -y -hide_banner -loglevel error  -i {file[0]} {pipe} {single_p} {params} - -o {file[1].with_suffix(".mkv")}',
+                (file[0], file[1].with_suffix('.mkv')))
+                for file in inputs
+                ]
+
+    if passes == 2:
+        commands = [
+            (f'ffmpeg -y -hide_banner -loglevel error -i {file[0]} {pipe} {two_p_1} {params} - --stats {file[0].with_suffix(".log")} - -o {os.devnull}',
+             f'ffmpeg -y -hide_banner -loglevel error -i {file[0]} {pipe} {two_p_2} {params} - --stats {file[0].with_suffix(".log")} - -o {file[1].with_suffix(".mkv")}',
+             (file[0], file[1].with_suffix('.mkv')))
+             for file in inputs
+        ]
+    return commands
+
 def x265_encode(inputs, passes, pipe, params):
     """
-    Generates commands for AOM, VPX encoders
+    Generates commands for x265 encoder
 
     :param inputs: Files that need to be enocoded
     :param passes: Encoding passes
@@ -162,8 +196,8 @@ def x265_encode(inputs, passes, pipe, params):
     """
     commands = []
     single_p = 'x265 --y4m'
-    two_p_1 = 'x265 --pass 1 --y4m'
-    two_p_2 = 'x265 --pass 2 --y4m'
+    two_p_1 = 'x265 --log-level error --pass 1 --y4m'
+    two_p_2 = 'x265 --log-level error --pass 2 --y4m'
 
     if passes == 1:
         commands = [
@@ -183,6 +217,24 @@ def x265_encode(inputs, passes, pipe, params):
     return commands
 
 
+def vvc_encode(inputs, params, vvc_conf):
+    """
+    Generates commands for VCC encoder with yuv as input + get set frame count.
+    1 pass only/
+
+    :param inputs: Files that need to be enocoded
+    :param params: Encoding parameters
+    :return: Composed commands for execution
+    """
+    commands = [
+        (f'vvc_encoder -c {vvc_conf} -i {x[0].with_suffix(".yuv").as_posix()} {params} -f {frame_probe(x[0])} --InputBitDepth=10 --OutputBitDepth=10 -b {x[1].with_suffix(".h266")}',
+        (x[0], x[1].with_suffix(".h266")))
+        for x in inputs
+        ]
+
+    return commands
+
+
 def compose_encoding_queue(files, args):
     """
     Composing encoding queue with split videos.
@@ -197,6 +249,7 @@ def compose_encoding_queue(files, args):
 
     encoders = {'svt_av1': 'SvtAv1EncApp', 'rav1e': 'rav1e', 'aom': 'aomenc', 'vpx': 'vpxenc', 'x265': 'x265'}
     enc_exe = encoders.get(args.encoder)
+
     inputs = [(args.temp / "split" / file.name,
                args.temp / "encode" / file.name,
                file) for file in files]
@@ -217,6 +270,12 @@ def compose_encoding_queue(files, args):
     elif args.encoder == 'x265':
         queue = x265_encode(inputs, args.passes, args.ffmpeg_pipe, args.video_params)
 
+    elif args.encoder == 'x264':
+        queue = x264_encode(inputs, args.passes, args.ffmpeg_pipe, args.video_params)
+
+    elif args.encoder == 'vvc':
+        queue = vvc_encode(inputs, args.video_params, args.vvc_conf)
+
     # Catch Error
     if len(queue) == 0:
         er = 'Error in making command queue'
