@@ -1,9 +1,9 @@
 #!/usr/bin/env python3
 import time
 import json
+import os
 from pathlib import Path
 from .target_vmaf import target_vmaf
-from .boost import boosting
 from .utils import  frame_probe_cv2, terminate, process_inputs
 from .fp_reuse import remove_first_pass_from_commands
 from .utils import man_q
@@ -22,6 +22,7 @@ from .fp_reuse import segment_first_pass
 from .split import extra_splits, segment, split_routine
 from .vmaf import plot_vmaf
 import shutil
+from .vvc import to_yuv, vvc_concat
 
 
 def video_encoding(args):
@@ -58,7 +59,10 @@ def video_encoding(args):
         encoding_loop(args, commands)
 
         try:
-            concatenate_video(args.temp, args.output_file, args.encoder )
+            if args.encoder == 'vvc':
+                vvc_concat(args.temp, args.output_file.with_suffix('.h266'))
+            else:
+                concatenate_video(args.temp, args.output_file, args.encoder )
 
         except Exception as e:
             _, _, exc_tb = sys.exc_info()
@@ -67,7 +71,7 @@ def video_encoding(args):
             terminate()
 
         if args.vmaf or args.vmaf_plots:
-            plot_vmaf(args.input, args.output_file, args.vmaf_path)
+            plot_vmaf(args.input, args.output_file, args.vmaf_path, args.vmaf_res)
         # Delete temp folders
         if not args.keep:
             shutil.rmtree(args.temp)
@@ -169,11 +173,6 @@ def encode(commands):
             else:
                 commands = (cm1,) + commands[1:]
 
-        # Boost
-        if args.boost:
-            commands = boosting(args.boost_limit, args.boost_range, source, commands, args.passes)
-
-        # first pass reuse
         if args.reuse_first_pass:
             commands = remove_first_pass_from_commands(commands, args.passes)
 
@@ -181,11 +180,21 @@ def encode(commands):
 
         # Queue execution
         for i in commands[:-1]:
+                if args.encoder == 'vvc':
+                    log(f'Creating yuv for file {commands[1][0]}\n')
+                    fl = to_yuv(commands[1][0])
+                    log(f'Created yuv for file {commands[1][0]}\n')
                 tqdm_bar(i, args.encoder, counter, frame_probe_source, args.passes)
 
+                if args.encoder == 'vvc':
+                    os.remove(fl)
+
         frame_check(source, target, args.temp, args.no_check)
 
-        frame_probe_fr = frame_probe(target)
+        if args.encoder == 'vvc':
+            frame_probe_fr = frame_probe(source)
+        else:
+             frame_probe_fr = frame_probe(target)
 
         enc_time = round(time.time() - st_time, 2)
 
